@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2019-2020 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,8 +23,7 @@
 
 #include <grantlee/markupdirector.h>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class MarkupDirector : public Grantlee::MarkupDirector
 {
 public:
