@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2019-2020 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -289,7 +289,7 @@ void PlainTextMarkupBuilder::endList()
 void PlainTextMarkupBuilder::beginListItem()
 {
     Q_D(PlainTextMarkupBuilder);
-    for (auto i = 0; i < d->currentListItemNumbers.size(); i++) {
+    for (int i = 0, total = d->currentListItemNumbers.size(); i < total; ++i) {
         d->m_text.append(QStringLiteral("    "));
     }
 
