@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -36,7 +36,7 @@ public:
     InsertTableDialogPrivate(InsertTableDialog *qq)
         : q(qq)
     {
-        q->setWindowTitle(i18n("Insert Table"));
+        q->setWindowTitle(i18nc("@title:window", "Insert Table"));
         QVBoxLayout *mainLayout = new QVBoxLayout(q);
 
         insertTableWidget = new InsertTableWidget(q);
