@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -41,7 +41,7 @@ public:
     TableFormatDialogPrivate(TableFormatDialog *qq)
         : q(qq)
     {
-        q->setWindowTitle(i18n("Table Format"));
+        q->setWindowTitle(i18nc("@title:window", "Table Format"));
         QVBoxLayout *mainLayout = new QVBoxLayout(q);
 
         QWidget *page = new QWidget(q);
